@@ -8,6 +8,11 @@ from molgraph import chemistry
 from molgraph.tensors import GraphTensor
 from molgraph.tensors import GraphTensorSpec
 
+# filter out some warnings
+from molgraph import _filter_warnings
+
+del _filter_warnings
+
 from . import _version
 
 __version__ = _version.__version__
