@@ -20,8 +20,8 @@ from dataclasses import dataclass, field
 from abc import ABC, abstractmethod
 
 from molgraph.tensors.graph_tensor import GraphTensor
-from molgraph.chemistry.atomic.featurizers import AtomicFeaturizer
-from molgraph.chemistry.atomic.tokenizers import AtomicTokenizer
+from molgraph.chemistry.encoders import Featurizer
+from molgraph.chemistry.encoders import Tokenizer
 from molgraph.chemistry.ops import molecule_from_string
 
 
@@ -33,19 +33,16 @@ class BaseMolecularGraphEncoder(ABC):
 
     'Base class for ``MolecularGraphEncoder`` and ``MolecularGraphEncoder3D``.'
 
-    atom_encoder: Union[AtomicFeaturizer, AtomicTokenizer, Callable]
+    atom_encoder: Union[Featurizer, Tokenizer, Callable]
 
     @abstractmethod
-    def call(
-        self,
-        molecule: Union[str, Chem.Mol],
-        **kwargs,
-    ) -> GraphTensor:
+    def call(self, molecule, **kwargs) -> GraphTensor:
         pass
 
     def __call__(
         self,
         inputs: Sequence[Union[str, Chem.Mol]],
+        *,
         processes: Optional[int] = None,
         device: str = '/cpu:0',
         **kwargs,
@@ -77,14 +74,14 @@ class BaseMolecularGraphEncoder(ABC):
             molecule(s) inputted.
         '''
         with tf.device(device):
+
             if isinstance(inputs, (list, tuple, set, np.ndarray)):
                 # Convert a list of inputs to a list of `GraphTensor`s.
                 # To lower the run-time, multiprocessing is used.
                 with multiprocessing.Pool(processes) as pool:
                     graph_tensor_list = pool.map(
                         func=partial(self.call, **kwargs),
-                        iterable=inputs
-                    )
+                        iterable=inputs)
 
                 graph_tensor_list = [
                     gt for gt in graph_tensor_list if gt is not None]
@@ -104,9 +101,9 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
     '''Molecular graph encoder, encoding molecular graphs as ``GraphTensor``.
 
     Args:
-        atom_encoder (AtomicFeaturizer, AtomicTokenizer):
+        atom_encoder (Featurizer, Tokenizer):
             The atom encoder to use.
-        bond_encoder (AtomicFeaturizer, AtomicTokenizer, None):
+        bond_encoder (Featurizer, Tokenizer, None):
             The bond encoder to use. Default to None.
         molecule_from_string_fn (callable):
             A function that produces an RDKit molecule object from some input,
@@ -129,13 +126,13 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
     Generate a molecular graph with featurizers:
 
     >>> # Define atom featurizer (to produce numerical encoding of atoms)
-    >>> atom_featurizer = molgraph.chemistry.AtomicFeaturizer([
+    >>> atom_featurizer = molgraph.chemistry.Featurizer([
     ...     molgraph.chemistry.features.Symbol(),
     ...     molgraph.chemistry.features.Hybridization()
     ...     # ...
     ... ])
     >>> # Define bond featurizer (to produce numerical encoding of bonds)
-    >>> bond_featurizer = molgraph.chemistry.AtomicFeaturizer([
+    >>> bond_featurizer = molgraph.chemistry.Featurizer([
     ...     molgraph.chemistry.features.BondType(),
     ...     # ...
     ... ])
@@ -161,13 +158,13 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
     Generate a molecular graph with tokenizers:
 
     >>> # Define bond featurizer (to produce numerical encoding of atoms)
-    >>> atom_tokenizer = molgraph.chemistry.AtomicTokenizer([
+    >>> atom_tokenizer = molgraph.chemistry.Tokenizer([
     ...     molgraph.chemistry.features.Symbol(),
     ...     molgraph.chemistry.features.Hybridization()
     ...     # ...
     ... ])
     >>> # Define bond featurizer (to produce numerical encoding of bonds)
-    >>> bond_tokenizer = molgraph.chemistry.AtomicTokenizer([
+    >>> bond_tokenizer = molgraph.chemistry.Tokenizer([
     ...     molgraph.chemistry.features.BondType(),
     ...     # ...
     ... ])
@@ -195,12 +192,12 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
     when tokenizers are used to compute ``node_feature`` and ``edge_feature``:
 
     >>> # Define bond featurizer (to produce numerical encoding of atoms)
-    >>> atom_tokenizer = molgraph.chemistry.AtomicTokenizer([
+    >>> atom_tokenizer = molgraph.chemistry.Tokenizer([
     ...    molgraph.chemistry.features.Symbol(),
     ...    molgraph.chemistry.features.Hybridization()
     ... ])
     >>> # Define bond featurizer (to produce numerical encoding of bonds)
-    >>> bond_tokenizer = molgraph.chemistry.AtomicTokenizer([
+    >>> bond_tokenizer = molgraph.chemistry.Tokenizer([
     ...    molgraph.chemistry.features.BondType(),
     ... ])
     >>> # Define molecular graph encoder
@@ -242,7 +239,7 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
     '''
 
     bond_encoder: Optional[Union[
-        AtomicFeaturizer, AtomicTokenizer, Callable]] = None
+        Featurizer, Tokenizer, Callable]] = None
     molecule_from_string_fn: Callable[[str], Chem.Mol] = field(
         default_factory=lambda: partial(molecule_from_string, catch_errors=True),
         repr=False
@@ -255,6 +252,7 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
     def call(
         self,
         molecule: Union[str, Chem.Mol],
+        *,
         index_dtype: str = 'int32'
     ) -> GraphTensor:
 
@@ -288,7 +286,8 @@ class MolecularGraphEncoder(BaseMolecularGraphEncoder):
         # Obtain edge (bond) features (if `bond_encoder` exist)
         if self.bond_encoder is not None:
             bonds = _get_bonds(molecule, *sparse_adjacency)
-            data['edge_feature'] = self.bond_encoder(bonds)
+            data['edge_feature'] = self.bond_encoder(
+                bonds, self_loops=self.self_loops)
 
         # Obtain positional encoding of nodes (atoms)
         if self.positional_encoding_dim:
@@ -311,7 +310,7 @@ class MolecularGraphEncoder3D(BaseMolecularGraphEncoder):
     as ``GraphTensor``.
 
     Args:
-        atom_encoder (AtomicFeaturizer, AtomicTokenizer):
+        atom_encoder (Featurizer, Tokenizer):
             The atom encoder to use.
         molecule_from_string_fn (callable):
             A function that produces an RDKit molecule object from some input,
@@ -330,7 +329,7 @@ class MolecularGraphEncoder3D(BaseMolecularGraphEncoder):
     **Examples:**
 
     >>> # Define bond featurizer (to produce numerical encoding of atoms)
-    >>> atom_featurizer = molgraph.chemistry.AtomicFeaturizer([
+    >>> atom_featurizer = molgraph.chemistry.Featurizer([
     ...     molgraph.chemistry.features.Symbol(),
     ...     molgraph.chemistry.features.Hybridization()
     ...     # ...
@@ -378,6 +377,7 @@ class MolecularGraphEncoder3D(BaseMolecularGraphEncoder):
     def call(
         self,
         molecule: str,
+        *,
         index_dtype: str = 'int32'
     ) -> GraphTensor:
 
@@ -418,8 +418,7 @@ class MolecularGraphEncoder3D(BaseMolecularGraphEncoder):
 
 
 def _get_atoms(molecule: Chem.Mol) -> List[Chem.Atom]:
-    """Returns a list of atoms given an RDKit mol object.
-    """
+    'Returns a list of atoms given an RDKit mol object.'
     return list(molecule.GetAtoms())
 
 def _get_bonds(
@@ -427,10 +426,10 @@ def _get_bonds(
     edge_dst: np.ndarray,
     edge_src: np.ndarray
 ) -> List[Chem.Bond]:
-    """Returns a list of bonds given an RDKit mol object. The order of the
+    '''Returns a list of bonds given an RDKit mol object. The order of the
     bonds in the list corresponds to the sparse adjacency matrix which is
     also part of the resulting `GraphTensor`.
-    """
+    '''
     return [
         molecule.GetBondBetweenAtoms(int(i), int(j))
         for (i, j) in zip(edge_dst, edge_src)
@@ -441,13 +440,13 @@ def _compute_positional_encoding(
     dim: int = 20,
     dtype: np.dtype = np.float32,
 ) -> np.ndarray:
-    """Computes Laplacian positional encoding from a RDKit molecule object.
+    '''Computes Laplacian positional encoding from a RDKit molecule object.
 
     The laplacian positional encoding encodes the position of nodes (atoms) in
-    the molecular graph. This could be seen as a replacement for the typical
+    the molecular graph. This could be seen as a replacement for the
     positional encoding of the transformer models for natural language
     processing tasks (e.g. BERT).
-    """
+    '''
 
     # If the molecule only has one atom, return a zero vector
     if molecule.GetNumAtoms() <= 1:
@@ -478,9 +477,9 @@ def _compute_sorted_eigen_vectors(
     laplacian: np.ndarray,
     dtype: np.dtype = np.float32
 ) -> np.ndarray:
-    """Computes eigen vectors of the laplacian matrix, sorted by the
+    '''Computes eigen vectors of the laplacian matrix, sorted by the
     eigen values.
-    """
+    '''
     eigen_values, eigen_vectors = np.linalg.eig(laplacian)
     indices = eigen_values.argsort()
     eigen_values = eigen_values[indices]
@@ -493,9 +492,7 @@ def _compute_adjacency(
     sparse: bool = False,
     dtype: np.dtype = np.int32,
 ) -> Tuple[np.ndarray, np.ndarray]:
-    """Computes an adjacency matrix or a sparse adjacency matrix from an
-    RDKit molecule object.
-    """
+    'Computes (sparse) adjacency matrix from an RDKit molecule object.'
 
     adjacency = Chem.GetAdjacencyMatrix(molecule)
 
@@ -513,8 +510,7 @@ def _compute_laplacian(
     adjacency: np.ndarray,
     dtype: np.dtype = np.float32
 ) -> np.ndarray:
-    """Computes the laplacian matrix an adjacency matrix
-    """
+    'Computes the laplacian matrix an adjacency matrix.'
     degree = np.sum(adjacency, axis=1)
     degree = np.sqrt(degree)
     degree = np.divide(1., degree, out=np.zeros_like(degree), where=degree!=0)
@@ -529,7 +525,7 @@ def _compute_distance_between_atoms(
     edge_src: int,
     unit: str
 ) -> float:
-    '''Computes distance between two atoms in the molecule'''
+    'Computes distance between two atoms in the molecule.'
     bond_length = Chem.rdMolTransforms.GetBondLength(
         molecule.GetConformer(), edge_dst, edge_src)
     if unit.lower() == 'bohr':
