@@ -22,7 +22,7 @@ class GradientActivationMapping(keras.Model):
     **Example:**
 
     >>> encoder = molgraph.chemistry.MolecularGraphEncoder(
-    ...     atom_encoder=molgraph.chemistry.AtomicFeaturizer([
+    ...     atom_encoder=molgraph.chemistry.Featurizer([
     ...         molgraph.chemistry.features.Symbol(),
     ...         molgraph.chemistry.features.Hybridization()
     ...     ])
@@ -41,7 +41,7 @@ class GradientActivationMapping(keras.Model):
     ...     tf.keras.layers.Dense(units=1)
     ... ])
     >>> gnn_model.compile(optimizer='adam', loss='mse')
-    >>> gnn_model.fit(esol['train']['x'], esol['train']['y'], epochs=10)
+    >>> _ = gnn_model.fit(esol['train']['x'], esol['train']['y'], epochs=10, verbose=0)
     >>> gam_model = molgraph.models.GradientActivationMapping(
     ...     model=gnn_model,
     ...     layer_names=['gcn_conv_1', 'gcn_conv_2', 'gcn_conv_3'],
